ConditionalMultiIndex

Struct ConditionalMultiIndex 

pub struct ConditionalMultiIndex<'a, K, T> { /* private fields */ }

Implementations

Source

impl<'a, K, T> ConditionalMultiIndex<'a, K, T>

pub const fn new_ref( idx_fn: fn(&T, Vec<u8>) -> K, cond_fn: fn(&T) -> bool, dese_fn: Option<DeserializeFn<T>>, pk_namespace: &'a str, idx_namespace: &'a str, ) -> Self

Only if result of cond_fn is true, data will be added to this ConditionalMultiIndex.

Result of cond_fn must be constant, otherwise might raise unexpected behavior.

pub const fn new_owned( idx_fn: fn(&T, Vec<u8>) -> K, cond_fn: fn(&T) -> bool, dese_fn: Option<DeserializeFn<T>>, pk_namespace: String, idx_namespace: String, ) -> Self

Only if result of cond_fn is true, data will be added to this ConditionalMultiIndex.

Result of cond_fn must be constant, otherwise might raise unexpected behavior.

Source

impl<'a, K, T> ConditionalMultiIndex<'a, K, T>
where T: Serialize + DeserializeOwned + Clone, K: for<'key> PrimaryKey<'key>,

pub fn prefix(&self, p: <K as PrimaryKey<'_>>::Prefix) -> Prefix<T>

pub fn sub_prefix(&self, p: <K as PrimaryKey<'_>>::SubPrefix) -> Prefix<T>

pub fn index_key(&self, k: K) -> Vec<u8>